document.addEventListener('DOMContentLoaded', () => {
  const eventForm = document.getElementById('eventForm');
  const eventsList = document.getElementById('eventsList');
  
  // Load events from localStorage
  let events = JSON.parse(localStorage.getItem('events')) || [];
  
  eventForm.addEventListener('submit', (e) => {
    e.preventDefault();
    
    const name = document.getElementById('eventName').value;
    const date = document.getElementById('eventDate').value;
    
    const newEvent = {
      id: Date.now(),
      name,
      date: new Date(date).getTime()
    };
    
    events.push(newEvent);
    localStorage.setItem('events', JSON.stringify(events));
    
    renderEvents();
    eventForm.reset();
  });
  
  function renderEvents() {
    eventsList.innerHTML = '';
    
    events.forEach(event => {
      const card = document.createElement('div');
      card.className = 'event-card';
      
      const countdown = createCountdownHTML(event);
      
      card.innerHTML = `
        <h3 class="event-name">${event.name}</h3>
        ${countdown}
        <button onclick="deleteEvent(${event.id})" class="delete-btn">Delete</button>
      `;
      
      eventsList.appendChild(card);
    });
  }
  
  function createCountdownHTML(event) {
    const now = new Date().getTime();
    const distance = event.date - now;
    
    const days = Math.floor(distance / (1000 * 60 * 60 * 24));
    const hours = Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
    const minutes = Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60));
    const seconds = Math.floor((distance % (1000 * 60)) / 1000);
    
    return `
      <div class="countdown">
        <div class="time-unit">
          <div class="time-value">${days}</div>
          <div class="time-label">Days</div>
        </div>
        <div class="time-unit">
          <div class="time-value">${hours}</div>
          <div class="time-label">Hours</div>
        </div>
        <div class="time-unit">
          <div class="time-value">${minutes}</div>
          <div class="time-label">Minutes</div>
        </div>
        <div class="time-unit">
          <div class="time-value">${seconds}</div>
          <div class="time-label">Seconds</div>
        </div>
      </div>
    `;
  }
  
  window.deleteEvent = (id) => {
    events = events.filter(event => event.id !== id);
    localStorage.setItem('events', JSON.stringify(events));
    renderEvents();
  };
  
  // Update countdowns every second
  setInterval(renderEvents, 1000);
  
  // Initial render
  renderEvents();
});
